==> haskell-cracknum-2.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crackNum
version:              2.3
visibility:           public
id:                   crackNum-2.3-5wzdqqnhc4L2OEYbKaHIPy
key:                  crackNum-2.3-5wzdqqnhc4L2OEYbKaHIPy
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
homepage:             http://github.com/LeventErkok/CrackNum
synopsis:             Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.

    For details, please see: <http://github.com/LeventErkok/crackNum/>

category:             Tools
abi:                  2a269f6cbb2145acba2d5b2c326381c2
exposed:              True
exposed-modules:      Data.Numbers.CrackNum
hidden-modules:
    Data.Numbers.CrackNum.Utils Data.Numbers.CrackNum.Data

import-dirs:          /usr/lib/ghc-8.8.3/site-local/crackNum-2.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/crackNum-2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/crackNum-2.3
hs-libraries:         HScrackNum-2.3-5wzdqqnhc4L2OEYbKaHIPy
depends:
    FloatingHex-0.4-HBuF3AVXDMJCGHQvWDd2Db array-0.5.4.0 base-4.13.0.0

haddock-interfaces:   /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html:         /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cracknum-2.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crackNum
version:              2.3
visibility:           public
id:                   crackNum-2.3-CQbay1ksqI3HndLiMNHQcr
key:                  crackNum-2.3-CQbay1ksqI3HndLiMNHQcr
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
homepage:             http://github.com/LeventErkok/CrackNum
synopsis:             Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.

    For details, please see: <http://github.com/LeventErkok/crackNum/>

category:             Tools
abi:                  38d79c5e1aa9b22faf108ab39066d471
exposed:              True
exposed-modules:      Data.Numbers.CrackNum
hidden-modules:
    Data.Numbers.CrackNum.Utils Data.Numbers.CrackNum.Data

import-dirs:          /usr/lib/ghc-8.10.1/site-local/crackNum-2.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/crackNum-2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/crackNum-2.3
hs-libraries:         HScrackNum-2.3-CQbay1ksqI3HndLiMNHQcr
depends:
    FloatingHex-0.4-B2JmOQsAjjd4PESjEpQjAq array-0.5.4.0 base-4.14.0.0

haddock-interfaces:   /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html:         /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
